# Artificial Neural Network for brain tumor detection
![License](https://img.shields.io/badge/License-GPL_2.0-green)
![python](https://img.shields.io/badge/Python-3.9.12-blue)
![Numpy](https://img.shields.io/badge/Numpy-1.21.5-blue)
![Skimage](https://img.shields.io/badge/Scikit_Image-0.19.2-blue)
![Sklearn](https://img.shields.io/badge/Scikit_Learn-1.0.2-blue)
![Matplotlib](https://img.shields.io/badge/Matplotlib-3.5.1-blue)
![Pickle](https://img.shields.io/badge/-Pickle-blue)
![Random](https://img.shields.io/badge/-Random-blue)

# Index
Este é um pacote destinado a implementação dos conceitos de visão computacional e processamento de imagens.

<h4 align="center"> 
	🚧  Status 🚀 Em construção...  🚧
</h4>

# Infos
Este pacote contém uma rede neural implementada do zero, somente usando o numpy. Também contém funcionalidades para o processamento de imagens e extração de atributos.

# Pré-requeriments
As depêndencias deste pacote são:
- numpy
- scikit-image
- scikit-learn
- matplotlib
- pickle


